import logging
from abc import ABC, abstractmethod

logger = logging.getLogger(__name__)  # Initialize logger


class AbstractScanner(ABC):
    """
    Base `Scanner` class. To be overwritten with other scanning logic.
    """

    @abstractmethod
    async def scan(self, guid, content, chain):
        """Override this to implement custom scanning logic

        Args:
            guid (str): GUID of the bounty under analysis, use to track artifacts in the same bounty
            content (bytes): Content of the artifact to be scan
        Returns:
            Tuple(bool, bool, str): Tuple of bit, verdict, metadata

        Note:
            | The meaning of the return types are as follows:
            |   - **bit** (*bool*): Whether to include this artifact in the assertion or not
            |   - **verdict** (*bool*): Whether this artifact is malicious or not
            |   - **metadata** (*str*): Optional metadata about this artifact
        """
        pass
